## Pytest Plugin to show real test coverage

### TLTR

With this plugin you will be able to see all methods in project with the number of their tests

Just call:
```
pytest --pointers-report -v
```

![](https://jaklimoff-misc.s3.eu-central-1.amazonaws.com/pytest-pointers/example_output.jpg)
